@@ -394,6 +394,10 @@ fn create_lines(
             .collect::<Vec<_>>();
 
         lines.push(Line::from(spans));
+
+        if !content[line.clone()].ends_with('\n') {
+            lines.push(Line::from("\\ No newline at end of file"))
+        }
     }
 }
 
@@ -496,6 +500,12 @@ mod tests {
         insta::assert_snapshot!(hunks[0].format_patch());
     }
 
+    #[test]
+    fn changed_line_no_newline() {
+        let hunks = diff_content("old line", "new line");
+        insta::assert_snapshot!(hunks[0].format_patch());
+    }
+
     #[test]
     fn multiple_changed_lines() {
         let hunks = diff_content("one\ntwo\nthree\n", "three\ntwo\none\n");
